package at.acdp.urweb.sclient.data;

import at.acdp.urweb.CountDataInputStream;

import java.io.IOException;

public class MasterBoardData implements IRead, ILogentry {
    int digitalInputBits;
    int digitalOutputBits;
    int analogInputRange0;
    int analogInputRange1;
    double analogInput0;
    double analogInput1;
    byte analogOutputDomain0;
    byte analogOutputDomain1;
    double analogOutput0;
    double analogOutput1;
    float masterboardTemperature;
    float robotVoltage48V;
    float robotCurrent;
    float masterIOCurrent;
    int safetymode;
    int inReducedMode;
    byte euromap67Installed;
    int euromapInputBits;
    int euromapOutputBits;
    float euromapVoltage;
    float euromapCurrent;
    int internal;
    int operationalModeSelectorInput;
    int threePositionEnablingDeviceInput;

    @Override
    public void read(CountDataInputStream di, int size) throws IOException {

        digitalInputBits = di.readInt();
        digitalOutputBits = di.readInt();
        analogInputRange0 = di.readUnsignedByte();
        analogInputRange1 = di.readUnsignedByte();
        analogInput0 = di.readDouble();
        analogInput1 = di.readDouble();

        analogOutputDomain0 = di.readByte();
        analogOutputDomain1 = di.readByte();
        analogOutput0 = di.readDouble();
        analogInput1 = di.readDouble();
        masterboardTemperature = di.readFloat();
        robotVoltage48V = di.readFloat();
        robotCurrent = di.readFloat();
        masterIOCurrent = di.readFloat();
        safetymode = di.readByte();
        inReducedMode = di.readByte();
        euromap67Installed = di.readByte();
        if (euromap67Installed > 0) {
            euromapInputBits = di.readInt();
            euromapOutputBits = di.readInt();
            euromapVoltage = di.readFloat();
            euromapCurrent = di.readFloat();
        }
        internal = di.readInt();
        operationalModeSelectorInput = di.readUnsignedByte();
        threePositionEnablingDeviceInput = di.readUnsignedByte();
    }

    @Override
    public String toString() {
        return "MasterBoardData{" +
                "digitalInputBits=" + digitalInputBits +
                ", digitalOutputBits=" + digitalOutputBits +
                ", analogInputRange0=" + analogInputRange0 +
                ", analogInputRange1=" + analogInputRange1 +
                ", analogInput0=" + analogInput0 +
                ", analogInput1=" + analogInput1 +
                ", analogOutputDomain0=" + analogOutputDomain0 +
                ", analogOutputDomain1=" + analogOutputDomain1 +
                ", analogOutput0=" + analogOutput0 +
                ", analogOutput1=" + analogOutput1 +
                ", masterboardTemperature=" + masterboardTemperature +
                ", robotVoltage48V=" + robotVoltage48V +
                ", robotCurrent=" + robotCurrent +
                ", masterIOCurrent=" + masterIOCurrent +
                ", safetymode=" + safetymode +
                ", inReducedMode=" + inReducedMode +
                ", euromap67Installed=" + euromap67Installed +
                ", euromapInputBits=" + euromapInputBits +
                ", euromapOutputBits=" + euromapOutputBits +
                ", euromapVoltage=" + euromapVoltage +
                ", euromapCurrent=" + euromapCurrent +
                ", internal=" + internal +
                ", operationalModeSelectorInput=" + operationalModeSelectorInput +
                ", threePositionEnablingDeviceInput=" + threePositionEnablingDeviceInput +
                '}';
    }
}
